@@ -177,8 +177,9 @@ def _validate_subnet_list_or_none(data, key_specs=None):
     if data is not None:
         return validators.validate_subnet_list(data, key_specs)
 
+
 validators.add_validator('type:subnet_list_or_none',
-                        _validate_subnet_list_or_none)
+                         _validate_subnet_list_or_none)
 
 vpn_supported_initiators = ['bi-directional', 'response-only']
 vpn_supported_encryption_algorithms = ['3des', 'aes-128',
@@ -194,7 +195,7 @@ vpn_supported_pfs = ['group2', 'group5', 'group14']
 vpn_supported_ike_versions = ['v1', 'v2']
 vpn_supported_auth_mode = ['psk']
 vpn_supported_auth_algorithms = ['sha1', 'sha256', 'sha384', 'sha512']
-vpn_supported_phase1_negotiation_mode = ['main']
+vpn_supported_phase1_negotiation_mode = ['main', 'aggressive']
 
 vpn_lifetime_limits = (60, validators.UNLIMITED)
 positive_int = (0, validators.UNLIMITED)
