@@ -13,10 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import contextlib
+from unittest import mock
 
-import mock
 from neutron.db import servicetype_db as st_db
-from neutron.services.flavors.flavors_plugin import FlavorsPlugin
+from neutron.services.flavors import flavors_plugin
 from neutron.tests.unit.db import test_agentschedulers_db
 from neutron.tests.unit.extensions import test_agent as test_agent_ext_plugin
 
@@ -40,8 +40,8 @@ VPN_DRIVER_CLASS = 'neutron_vpnaas.services.vpn.plugin.VPNDriverPlugin'
 
 IPSEC_SERVICE_DRIVER = ('neutron_vpnaas.services.vpn.service_drivers.'
                         'ipsec.IPsecVPNDriver')
-CISCO_IPSEC_SERVICE_DRIVER = ('neutron_vpnaas.services.vpn.service_drivers.'
-                              'cisco_ipsec.CiscoCsrIPsecVPNDriver')
+DUMMY_IPSEC_SERVICE_DRIVER = ('neutron_vpnaas.tests.unit.dummy_ipsec.'
+                              'DummyIPsecVPNDriver')
 
 _uuid = uuidutils.generate_uuid
 
@@ -188,8 +188,8 @@ class TestVPNDriverPluginMultipleDrivers(base.BaseTestCase):
              'driver': IPSEC_SERVICE_DRIVER,
              'default': True},
             {'service_type': p_constants.VPN,
-             'name': 'cisco',
-             'driver': CISCO_IPSEC_SERVICE_DRIVER,
+             'name': 'dummy',
+             'driver': DUMMY_IPSEC_SERVICE_DRIVER,
              'default': False}]
         self.service_providers = (
             mock.patch.object(st_db.ServiceTypeManager,
@@ -219,8 +219,8 @@ class TestVPNDriverPluginMultipleDrivers(base.BaseTestCase):
             self.assertEqual('ipsec', driver_plugin.default_provider)
             self.assertIn('ipsec', driver_plugin.drivers)
             self.assertEqual('ipsec', driver_plugin.drivers['ipsec'].name)
-            self.assertIn('cisco', driver_plugin.drivers)
-            self.assertEqual('cisco', driver_plugin.drivers['cisco'].name)
+            self.assertIn('dummy', driver_plugin.drivers)
+            self.assertEqual('dummy', driver_plugin.drivers['dummy'].name)
 
     def test_provider_lost(self):
         LOST_SERVICE_ID = _uuid()
@@ -242,15 +242,15 @@ class TestVPNDriverPluginMultipleDrivers(base.BaseTestCase):
                 mock.ANY, p_constants.VPN, 'ipsec', UNASSO_SERVICE_ID)
 
     def test_get_driver_for_vpnservice(self):
-        CISCO_VPNSERVICE_ID = _uuid()
-        CISCO_VPNSERVICE = {'id': CISCO_VPNSERVICE_ID}
-        provider_names = {CISCO_VPNSERVICE_ID: 'cisco'}
+        DUMMY_VPNSERVICE_ID = _uuid()
+        DUMMY_VPNSERVICE = {'id': DUMMY_VPNSERVICE_ID}
+        provider_names = {DUMMY_VPNSERVICE_ID: 'dummy'}
         with self.vpnservices_providers_set(provider_names=provider_names):
             driver_plugin = vpn_plugin.VPNDriverPlugin()
             self.assertEqual(
-                driver_plugin.drivers['cisco'],
+                driver_plugin.drivers['dummy'],
                 driver_plugin._get_driver_for_vpnservice(
-                    self.adminContext, CISCO_VPNSERVICE))
+                    self.adminContext, DUMMY_VPNSERVICE))
 
     def test_get_driver_for_ipsec_site_connection(self):
         IPSEC_VPNSERVICE_ID = _uuid()
@@ -282,7 +282,8 @@ class TestVPNDriverPluginMultipleDrivers(base.BaseTestCase):
 
     def test_get_provider_for_flavor_id_invalid_type(self):
         FAKE_FLAVOR = {'service_type': 'NOT_VPN'}
-        directory.add_plugin(p_constants.FLAVORS, FlavorsPlugin())
+        directory.add_plugin(p_constants.FLAVORS,
+                             flavors_plugin.FlavorsPlugin())
         mock.patch(
             'neutron.services.flavors.flavors_plugin.FlavorsPlugin.get_flavor',
             return_value=FAKE_FLAVOR).start()
@@ -297,7 +298,8 @@ class TestVPNDriverPluginMultipleDrivers(base.BaseTestCase):
     def test_get_provider_for_flavor_id_flavor_disabled(self):
         FAKE_FLAVOR = {'service_type': p_constants.VPN,
                        'enabled': False}
-        directory.add_plugin(p_constants.FLAVORS, FlavorsPlugin())
+        directory.add_plugin(p_constants.FLAVORS,
+                             flavors_plugin.FlavorsPlugin())
         mock.patch(
             'neutron.services.flavors.flavors_plugin.FlavorsPlugin.get_flavor',
             return_value=FAKE_FLAVOR).start()
@@ -315,7 +317,8 @@ class TestVPNDriverPluginMultipleDrivers(base.BaseTestCase):
                        'service_type': p_constants.VPN,
                        'enabled': True}
         PROVIDERS = [{'provider': 'SOME_PROVIDER'}]
-        directory.add_plugin(p_constants.FLAVORS, FlavorsPlugin())
+        directory.add_plugin(p_constants.FLAVORS,
+                             flavors_plugin.FlavorsPlugin())
         mock.patch(
             'neutron.services.flavors.flavors_plugin.FlavorsPlugin.get_flavor',
             return_value=FAKE_FLAVOR).start()
@@ -336,8 +339,9 @@ class TestVPNDriverPluginMultipleDrivers(base.BaseTestCase):
         FAKE_FLAVOR = {'id': FLAVOR_ID,
                        'service_type': p_constants.VPN,
                        'enabled': True}
-        PROVIDERS = [{'provider': 'cisco'}]
-        directory.add_plugin(p_constants.FLAVORS, FlavorsPlugin())
+        PROVIDERS = [{'provider': 'dummy'}]
+        directory.add_plugin(p_constants.FLAVORS,
+                             flavors_plugin.FlavorsPlugin())
         mock.patch(
             'neutron.services.flavors.flavors_plugin.FlavorsPlugin.get_flavor',
             return_value=FAKE_FLAVOR).start()
@@ -348,6 +352,6 @@ class TestVPNDriverPluginMultipleDrivers(base.BaseTestCase):
         with self.vpnservices_providers_set():
             driver_plugin = vpn_plugin.VPNDriverPlugin()
             self.assertEqual(
-                'cisco',
+                'dummy',
                 driver_plugin._get_provider_for_flavor(
                     self.adminContext, FLAVOR_ID))
